@@ -219,6 +219,12 @@ hit_is_outbound (Hit *h)
 	return g_str_equal (h->direction, "Outbound");
 }
 
+static gboolean
+hit_is_inbound (Hit *h)
+{
+	return g_str_equal (h->direction, "Inbound");
+}
+
 /* [ hitview_append_hit ]
  * Append a hit to the hitlist, return true if successful
  */
@@ -256,10 +262,13 @@ hitview_append_hit (Hit *h)
 		status_event_out_inc ();
 		g_free (h->direction);
 		h->direction = g_strdup (_("Outbound")); /* Localize the direction */
-	} else {
+	} else if (hit_is_inbound (h)) {
 		status_event_in_inc ();
 		g_free (h->direction);
 		h->direction = g_strdup (_("Inbound"));
+	} else {
+		g_free (h->direction);
+		h->direction = g_strdup (_("Unknown"));
 	}
 
 	gtk_list_store_append (hitstore, &iter);
@@ -959,7 +968,7 @@ create_hitview_page (void)
 		"<b>", _("Blocked Connections"), "</b>", NULL));
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_box_pack_start (GTK_BOX (hitpagebox), frame, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hitpagebox), frame, FALSE, FALSE, GNOME_PAD_SMALL);
 
 	scrolledwin = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwin),
