@@ -14,26 +14,38 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 #include "firestarter.h"
 
 void hitview_clear (void);
 void hitview_reload (void);
+void hitview_reload_cancel (void);
+gboolean hitview_reload_in_progress (void);
+void hitview_abort_reload_callback (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data);
 gboolean hitview_append_hit (Hit *h);
 void hitview_toggle_column_visibility (GtkWidget *widget, gint colnum);
 
 Hit *hitview_get_selected_hit (void);
 GList *hitview_get_all_hits (void);
 
-void lookup_selected_hit (void);
+void hitview_lookup_selected_hit (void);
 void copy_selected_hit (void);
 const Hit *get_last_hit (void);
 
+void hitview_disable_events_selected_source (void);
+void hitview_disable_events_selected_port (void);
+
+void hitview_allow_host (void);
+void hitview_allow_service (void);
+void hitview_allow_service_from (void);
+
 GtkWidget *create_hitview_page (void);
 
 enum
 {
 	HITCOL_TIME,
+	HITCOL_DIRECTION,
 	HITCOL_IN,
 	HITCOL_OUT,
 	HITCOL_PORT,
@@ -43,6 +55,7 @@ enum
 	HITCOL_TOS,
 	HITCOL_PROTOCOL,
 	HITCOL_SERVICE,
+	HITCOL_COLOR,
 	NUM_HITCOLUMNS
 };
 
