@@ -64,7 +64,7 @@ logread_async_read_callback (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	if (result == GNOME_VFS_OK && bytes_read > 0) {
 	/* split line into (gchar **) and check for pattern */
 		lines = g_strsplit_set (info->buffer, "\n",-1);
-		while (*(lines+(i+info->half_line)) && (*lines != NULL)) {
+		while (*(lines+(i+info->half_line)) && (*lines+i != NULL)) {
 			if (g_pattern_match_string (info->pattern,*(lines+i) )) {
 				h = parse_log_line (*(lines+i));
 
