@@ -397,8 +397,8 @@ menus_initialize (GtkWidget *window)
 	gtk_icon_factory_add_default (icon_factory);
 
 	register_icon_set (icon_factory, FIRESTARTER_STOCK_WIZARD, icon_wizard);
-	register_icon_set (icon_factory, FIRESTARTER_STOCK_START_FIREWALL, icon_start_normal);
-	register_icon_set (icon_factory, FIRESTARTER_STOCK_STOP_FIREWALL, icon_stop_normal);
+	register_icon_set (icon_factory, FIRESTARTER_STOCK_START_FIREWALL, icon_start_toolbar);
+	register_icon_set (icon_factory, FIRESTARTER_STOCK_STOP_FIREWALL, icon_stop_toolbar);
 	register_icon_set (icon_factory, FIRESTARTER_STOCK_EDIT, icon_edit);
 	register_icon_set (icon_factory, FIRESTARTER_STOCK_LOCK_FIREWALL, icon_locked);
 	register_icon_set (icon_factory, FIRESTARTER_STOCK_UNLOCK_FIREWALL, icon_unlocked);
