@@ -47,29 +47,33 @@ write_outbound_script ()
 			 "OLDIFS=$IFS\n"
 			 "IFS=','\n\n");
 
+	fprintf (script, "# Allow response traffic\n"
+			 "$IPT -A OUTBOUND -p tcp -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
+			 "$IPT -A OUTBOUND -p udp -m state --state ESTABLISHED,RELATED -j ACCEPT\n\n");
+
 	fprintf (script, "if [ \"$OUTBOUND_POLICY\" == \"permissive\" ]; then\n");
 	fprintf (script, "	# Hosts to which traffic is denied\n"
 	                 "	while read host garbage\n"
 	                 "		do\n"
-	                 "			$IPT -A OUTBOUND -d $host -j LOG --log-level=info --log-prefix \"Outbound \"\n"
-	                 "			$IPT -A OUTBOUND -d $host -j REJECT\n"
+	                 "			$IPT -A OUTBOUND -d $host -j LSO\n"
 	                 "		done < "POLICY_OUT_DENY_TO"\n\n");
 
 	fprintf (script, "	# Hosts from which traffic is denied\n"
 	                 "	while read host garbage\n"
 	                 "		do\n"
-	                 "			$IPT -A OUTBOUND -s $host -j LOG --log-level=info --log-prefix \"Outbound \"\n"
-	                 "			$IPT -A OUTBOUND -s $host -j REJECT\n"
+	                 "			$IPT -A OUTBOUND -s $host -j LSO\n"
 	                 "		done < "POLICY_OUT_DENY_FROM"\n\n");
 
 	fprintf (script, "	# Services denied\n"
-	                 "	while read service port target garbage\n"
+	                 "	while read service ports target garbage\n"
 	                 "		do\n"
-			 "			scrub_parameters\n"
-	                 "			$IPT -A OUTBOUND -p tcp -s $target --dport $port -j LOG --log-level=info --log-prefix \"Outbound \"\n"
-	                 "			$IPT -A OUTBOUND -p tcp -s $target --dport $port -j REJECT\n"
-	                 "			$IPT -A OUTBOUND -p udp -s $target --dport $port -j LOG --log-level=info --log-prefix \"Outbound \"\n"
-	                 "			$IPT -A OUTBOUND -p udp -s $target --dport $port -j REJECT\n"
+			 "			IFS=' '\n"
+			 "			for port in `echo $ports`; do\n"
+			 "				scrub_parameters\n"
+	                 "				$IPT -A OUTBOUND -p tcp -s $target --dport $port -j LSO\n"
+	                 "				$IPT -A OUTBOUND -p udp -s $target --dport $port -j LSO\n"
+			 "			done\n"
+			 "			IFS=','\n"
 	                 "		done < "POLICY_OUT_DENY_SERVICE"\n\n");
 
 	fprintf (script, "	$IPT -A OUTBOUND -j ACCEPT # Default permissive policy \n");
@@ -87,15 +91,18 @@ write_outbound_script ()
 	                 "		done < "POLICY_OUT_ALLOW_FROM"\n\n");
 
 	fprintf (script, "	# Services allowed\n"
-	                 "	while read service port target garbage\n"
+	                 "	while read service ports target garbage\n"
 	                 "		do\n"
-			 "			scrub_parameters\n"
-	                 "			$IPT -A OUTBOUND -p tcp -s $target --dport $port -j ACCEPT\n"
-	                 "			$IPT -A OUTBOUND -p udp -s $target --dport $port -j ACCEPT\n"
+			 "			IFS=' '\n"
+			 "			for port in `echo $ports`; do\n"
+			 "				scrub_parameters\n"
+	                 "				$IPT -A OUTBOUND -p tcp -s $target --dport $port -j ACCEPT\n"
+	                 "				$IPT -A OUTBOUND -p udp -s $target --dport $port -j ACCEPT\n"
+			 "			done\n"
+			 "			IFS=','\n"
 	                 "		done < "POLICY_OUT_ALLOW_SERVICE"\n\n");
 
-	fprintf (script, "	$IPT -A OUTBOUND -j LOG --log-level=info --log-prefix \"Outbound \"\n"
-	                 "	$IPT -A OUTBOUND -j REJECT # Default restrictive policy\n");
+	fprintf (script, "	$IPT -A OUTBOUND -j LSO # Default restrictive policy\n");
 	fprintf (script, "fi\n\n");
 
 	fprintf (script, "# Restore system field separator\n"
@@ -126,8 +133,8 @@ write_inbound_script ()
 			 "IFS=','\n\n");
 
 	fprintf (script, "# Allow response traffic\n"
-			 "$IPT -A INBOUND -p tcp --dport 1024:65535 -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
-			 "$IPT -A INBOUND -p udp --dport 1023:65535 -m state --state ESTABLISHED,RELATED -j ACCEPT\n\n");
+			 "$IPT -A INBOUND -p tcp -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
+			 "$IPT -A INBOUND -p udp -m state --state ESTABLISHED,RELATED -j ACCEPT\n\n");
 
 	fprintf (script, "# Hosts from which connections are always allowed\n"
 	                 "while read host garbage\n"
@@ -136,14 +143,24 @@ write_inbound_script ()
 	                 "	done < "POLICY_IN_ALLOW_FROM"\n\n");
 
 	fprintf (script, "# Services allowed\n"
-	                 "while read service port target garbage\n"
+	                 "while read service ports target garbage\n"
 	                 "	do\n"
-			 "		scrub_parameters\n"
-	                 "		$IPT -A INBOUND -p tcp -s $target --dport $port -j ACCEPT\n"
-	                 "		$IPT -A INBOUND -p udp -s $target --dport $port -j ACCEPT\n"
+			 "		IFS=' '\n"
+			 "		for port in `echo $ports`; do\n"
+			 "			scrub_parameters\n"
+			 "			case \"$port\" in\n"
+			 "			  # Override broadcast blocking for Samba share discovery\n"
+			 "			  \"1900\" ) $IPT -I INPUT -p tcp -s $target --dport 1900 -j ACCEPT\n"
+			 "			           $IPT -I INPUT -p udp -s $target --dport 1900 -j ACCEPT;;\n"
+			 "			  # Default service handler\n"
+			 "			  * ) $IPT -A INBOUND -p tcp -s $target --dport $port -j ACCEPT\n"
+			 "			      $IPT -A INBOUND -p udp -s $target --dport $port -j ACCEPT;;\n"
+			 "			esac\n"
+			 "		done\n"
+			 "		IFS=','\n"
 	                 "	done < "POLICY_IN_ALLOW_SERVICE"\n\n");
 
-	fprintf (script, "$IPT -A INBOUND -j LS\n");
+	fprintf (script, "$IPT -A INBOUND -j LSI\n");
 
 	fprintf (script, "# Restore system field separator\n"
 			 "IFS=$OLDIFS\n\n");
@@ -469,35 +486,50 @@ write_netfilter_script (void)
 
    fprintf (script, "\n# --------( Chain Configuration - Create Default Result Chains )--------\n\n");
 
-	fprintf (script, "# Create a new log and stop (LS) chain.\n");
-	fprintf (script, "$IPT -N LS 2> /dev/null\n"
-	                 "$IPT -F LS\n"
-	                 "if [ \"$log_supported\" ]; then\n"
-	                 "	# Syn-flood protection\n"
-	                 "	$IPT -A LS -p tcp --syn -m limit --limit 1/s -j LOG --log-level=info --log-prefix \"Inbound \"\n"
-	                 "	$IPT -A LS -p tcp --syn -j $STOP_TARGET\n"
-	                 "	# Rapid portscan protection\n"
-	                 "	$IPT -A LS -p tcp --tcp-flags SYN,ACK,FIN,RST RST -m limit --limit 1/s -j LOG --log-level=info --log-prefix \"Inbound \"\n"
-	                 "	$IPT -A LS -p tcp --tcp-flags SYN,ACK,FIN,RST RST -j $STOP_TARGET\n"
-	                 "	# Ping of death protection\n"
-	                 "	$IPT -A LS -p icmp --icmp-type echo-request -m limit --limit 1/s -j LOG --log-level=info --log-prefix \"Inbound \"\n"
-	                 "	$IPT -A LS -p icmp --icmp-type echo-request -j $STOP_TARGET\n"
-	                 "	# Log everything\n"
-	                 "	$IPT -A LS -m limit --limit 5/s -j LOG --log-level=info --log-prefix \"Inbound \"\n"
-	                 "fi\n"
-	                 "$IPT -A LS -j $STOP_TARGET\n\n");
+	fprintf (script, "# Create a new chain for filtering the input before logging is performed\n"
+	                 "$IPT -N LOG_FILTER 2> /dev/null\n"
+	                 "$IPT -F LOG_FILTER\n\n");
 
 	fprintf (script, "# Hosts for which logging is disabled\n");
 	fprintf (script, "while read host garbage\n\tdo\n");
-	fprintf (script, "\t\t$IPT -I LS -s $host -j $STOP_TARGET\n");
+	fprintf (script, "\t\t$IPT -A LOG_FILTER -s $host -j $STOP_TARGET\n");
 	fprintf (script, "\tdone < "FIRESTARTER_FILTER_HOSTS_SCRIPT"\n\n");
 
 	fprintf (script, "# Ports for which logging is disabled\n");
 	fprintf (script, "while read port garbage\n\tdo\n");
-	fprintf (script, "\t\t$IPT -I LS -p tcp --dport $port -j $STOP_TARGET\n");
-	fprintf (script, "\t\t$IPT -I LS -p udp --dport $port -j $STOP_TARGET\n");
+	fprintf (script, "\t\t$IPT -A LOG_FILTER -p tcp --dport $port -j $STOP_TARGET\n");
+	fprintf (script, "\t\t$IPT -A LOG_FILTER -p udp --dport $port -j $STOP_TARGET\n");
 	fprintf (script, "\tdone < "FIRESTARTER_FILTER_PORTS_SCRIPT"\n\n");
 
+	fprintf (script, "# Create a new log and stop input (LSI) chain.\n");
+	fprintf (script, "$IPT -N LSI 2> /dev/null\n"
+	                 "$IPT -F LSI\n"
+	                 "$IPT -A LSI -j LOG_FILTER\n"
+	                 "if [ \"$log_supported\" ]; then\n"
+	                 "	# Syn-flood protection\n"
+	                 "	$IPT -A LSI -p tcp --syn -m limit --limit 1/s -j LOG --log-level=$LOG_LEVEL --log-prefix \"Inbound \"\n"
+	                 "	$IPT -A LSI -p tcp --syn -j $STOP_TARGET\n"
+	                 "	# Rapid portscan protection\n"
+	                 "	$IPT -A LSI -p tcp --tcp-flags SYN,ACK,FIN,RST RST -m limit --limit 1/s -j LOG --log-level=$LOG_LEVEL --log-prefix \"Inbound \"\n"
+	                 "	$IPT -A LSI -p tcp --tcp-flags SYN,ACK,FIN,RST RST -j $STOP_TARGET\n"
+	                 "	# Ping of death protection\n"
+	                 "	$IPT -A LSI -p icmp --icmp-type echo-request -m limit --limit 1/s -j LOG --log-level=$LOG_LEVEL --log-prefix \"Inbound \"\n"
+	                 "	$IPT -A LSI -p icmp --icmp-type echo-request -j $STOP_TARGET\n"
+	                 "	# Log everything\n"
+	                 "	$IPT -A LSI -m limit --limit 5/s -j LOG --log-level=$LOG_LEVEL --log-prefix \"Inbound \"\n"
+	                 "fi\n"
+	                 "$IPT -A LSI -j $STOP_TARGET # Terminate evaluation\n\n");
+
+	fprintf (script, "# Create a new log and stop output (LSO) chain.\n");
+	fprintf (script, "$IPT -N LSO 2> /dev/null\n"
+	                 "$IPT -F LSO\n"
+	                 "$IPT -A LSO -j LOG_FILTER\n"
+	                 "if [ \"$log_supported\" ]; then\n"
+	                 "	# Log everything\n"
+	                 "	$IPT -A LSO -m limit --limit 5/s -j LOG --log-level=$LOG_LEVEL --log-prefix \"Outbound \"\n"
+	                 "fi\n"
+	                 "$IPT -A LSO -j REJECT # Terminate evaluation\n\n");
+
 	fprintf (script, "\n# --------( Initial Setup - Nameservers )--------\n\n");
 
 	fprintf (script, "# Allow regular DNS traffic\n"
@@ -583,8 +615,8 @@ write_netfilter_script (void)
 	                 "		$IPT -A INPUT -p udp --dport 33434 -j ACCEPT\n"
 	                 "		$IPT -A FORWARD -p udp --dport 33434 -j ACCEPT\n"
 	                 "	else\n"
-			 "		$IPT -A INPUT -p udp --dport 33434 -j LS\n"
-			 "		$IPT -A FORWARD -p udp --dport 33434 -j LS\n"
+			 "		$IPT -A INPUT -p udp --dport 33434 -j LSI\n"
+			 "		$IPT -A FORWARD -p udp --dport 33434 -j LSI\n"
 			 "	fi\n");
 
 	fprintf (script, "	if [ \"$ICMP_MSTRACEROUTE\" = \"on\" ]; then\n"
@@ -626,8 +658,8 @@ write_netfilter_script (void)
 			 "	fi\n\n");
 
 	fprintf (script, "	# Catch ICMP traffic not allowed above\n"
-			 "	$IPT -A INPUT -p icmp -j LS\n"
-			 "	$IPT -A FORWARD -p icmp -j LS\n");
+			 "	$IPT -A INPUT -p icmp -j LSI\n"
+			 "	$IPT -A FORWARD -p icmp -j LSI\n");
 
 	fprintf (script, "else\n"
 	                 "	# Allow all ICMP traffic when filtering disabled\n"
@@ -680,14 +712,16 @@ write_netfilter_script (void)
 
    fprintf (script, "\n# --------( Rules Configuration - Inbound Traffic )--------\n\n");
 
-	fprintf (script, "# Block nonroutable IP Addresses\n"
-	                 "$IPT -N NR 2> /dev/null\n"
-			 "$IPT -F NR\n"
-	                 "while read block garbage\n"
-			 "	do\n"
-	                 "		$IPT -A NR -s $block -d $NET -i $IF -j LS\n"
-	                 "	done < "FIRESTARTER_NON_ROUTABLES_SCRIPT"\n"
-	                 "$IPT -A INPUT -s ! $NET -i $IF -j NR\n\n");
+	fprintf (script, "if [ \"$BLOCK_NON_ROUTABLES\" = \"on\" ]; then\n"
+	                 "	# Block traffic from non-routable address space on the public interfaces\n"
+	                 "	$IPT -N NR 2> /dev/null\n"
+			 "	$IPT -F NR\n"
+	                 "	while read block garbage\n"
+			 "		do\n"
+	                 "			$IPT -A NR -s $block -d $NET -i $IF -j LSI\n"
+	                 "		done < "FIRESTARTER_NON_ROUTABLES_SCRIPT"\n"
+	                 "	$IPT -A INPUT -s ! $NET -i $IF -j NR\n"
+			 "fi\n\n");
 
 	fprintf (script, "# Block Broadcast Traffic\n"
 	                 "if [ \"$BLOCK_EXTERNAL_BROADCAST\" = \"on\" ]; then\n"
@@ -722,7 +756,7 @@ write_netfilter_script (void)
 	                 "$IPT -A OUTPUT -d 0.0.0.0 -j DROP\n\n");
 
 	fprintf (script, "$IPT -A INPUT -m state --state INVALID -j DROP # Block Traffic with Invalid Flags\n");
-	fprintf (script, "$IPT -A INPUT -f -m limit --limit 10/minute -j LS # Block Traffic w/ Excessive Fragmented Packets\n");
+	fprintf (script, "$IPT -A INPUT -f -m limit --limit 10/minute -j LSI # Block Traffic w/ Excessive Fragmented Packets\n");
 
    fprintf (script, "\n# --------( Rules Configuration - Outbound Traffic )--------\n\n");
 	fprintf (script, "$IPT -A OUTPUT -m state --state INVALID -j DROP # Block Traffic w/ Invalid Flags\n\n");
@@ -746,18 +780,21 @@ write_netfilter_script (void)
 	                 "	$IPT -A OUTPUT -o $INIF -j OUTBOUND  # Check firewall to LAN traffic\n"
 	                 "	$IPT -A FORWARD -i $INIF -j OUTBOUND # Check LAN to Internet traffic\n\n"
 
-	                 "	# Allow response traffic\n"
-	                 "	$IPT -A FORWARD -p tcp -d $INNET --dport 1024:65535 -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
-	                 "	$IPT -A FORWARD -p udp -d $INNET --dport 1023:65535 -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
+	                 "	# Allow Internet to LAN response traffic\n"
+	                 "	$IPT -A FORWARD -p tcp -d $INNET -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
+	                 "	$IPT -A FORWARD -p udp -d $INNET -m state --state ESTABLISHED,RELATED -j ACCEPT\n"
 			 "fi\n");
 
 	fprintf (script, "\n# --------( User Defined Post Script )--------\n\n");
 	fprintf (script, "source "FIRESTARTER_USER_POST_SCRIPT"\n\n");
 
 	fprintf (script, "\n# --------( Unsupported Traffic Catch-All )--------\n\n"
-			 "$IPT -A INPUT -j LOG --log-level=info --log-prefix \"Unknown \"\n"
-			 "$IPT -A OUTPUT -j LOG --log-level=info --log-prefix \"Unknown \"\n"
-			 "$IPT -A FORWARD -j LOG --log-level=info --log-prefix \"Unknown \"\n\n");
+			 "$IPT -A INPUT -j LOG_FILTER\n"
+			 "$IPT -A INPUT -j LOG --log-level=$LOG_LEVEL --log-prefix \"Unknown Input\"\n"
+			 "$IPT -A OUTPUT -j LOG_FILTER\n"
+			 "$IPT -A OUTPUT -j LOG --log-level=$LOG_LEVEL --log-prefix \"Unknown Output\"\n"
+			 "$IPT -A FORWARD -j LOG_FILTER\n"
+			 "$IPT -A FORWARD -j LOG --log-level=$LOG_LEVEL --log-prefix \"Unknown Forward\"\n\n");
 
 	fprintf (script, "return 0\n");
 
