@@ -14,8 +14,7 @@
 
 #include <config.h>
 #include <gnome.h>
-#include "druid.h"
 
-void write_netfilter_script (Druid *data);
+void write_netfilter_script (void);
 
 #endif
