@@ -1447,12 +1447,12 @@ create_policyview_page (void)
 	                    -1);
 
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (policypage), hbox, FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (policypage), hbox, FALSE, FALSE, 7);
 
 	label = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (label), g_strconcat (
 		"<span weight=\"bold\">", _("Editing"), "</span>", NULL));
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
 
 	combo = gtk_combo_box_new_with_model (model);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
