@@ -117,6 +117,7 @@ struct _PreferencesDialog
 	GtkWidget *radio_deny_packets;
 	GtkWidget *check_block_external_broadcast;
 	GtkWidget *check_block_internal_broadcast;
+	GtkWidget *check_block_non_routables;
 };
 
 static GConfClient *client = NULL;
@@ -754,6 +755,7 @@ load_preferences (PreferencesDialog *dialog)
 	preferences_update_widget_from_conf (dialog->radio_deny_packets, PREFS_FW_DENY_PACKETS);
 	preferences_update_widget_from_conf (dialog->check_block_external_broadcast, PREFS_FW_BLOCK_EXTERNAL_BROADCAST);
 	preferences_update_widget_from_conf (dialog->check_block_internal_broadcast, PREFS_FW_BLOCK_INTERNAL_BROADCAST);
+	preferences_update_widget_from_conf (dialog->check_block_non_routables, PREFS_FW_BLOCK_NON_ROUTABLES);
 }
 
 static void
@@ -817,7 +819,7 @@ save_preferences (PreferencesDialog *dialog)
 	preferences_update_conf_from_widget (dialog->radio_deny_packets, PREFS_FW_DENY_PACKETS);
 	preferences_update_conf_from_widget (dialog->check_block_external_broadcast, PREFS_FW_BLOCK_EXTERNAL_BROADCAST);
 	preferences_update_conf_from_widget (dialog->check_block_internal_broadcast, PREFS_FW_BLOCK_INTERNAL_BROADCAST);
-
+	preferences_update_conf_from_widget (dialog->check_block_non_routables, PREFS_FW_BLOCK_NON_ROUTABLES);
 
 	scriptwriter_output_configuration ();
 
@@ -1013,6 +1015,7 @@ get_preferences_dialog (GtkWindow *parent)
 	dialog->radio_deny_packets = glade_xml_get_widget (gui, "radio_drop_packets");
 	dialog->check_block_external_broadcast = glade_xml_get_widget (gui, "check_block_external_broadcast");
 	dialog->check_block_internal_broadcast = glade_xml_get_widget (gui, "check_block_internal_broadcast");
+	dialog->check_block_non_routables = glade_xml_get_widget (gui, "check_block_non_routables");
 
 	select_first_section (GTK_TREE_VIEW (sections));
 	/* Set the default page */
