@@ -15,7 +15,6 @@
 #include <config.h>
 #include <gnome.h>
 
-void savelog (GtkWidget *widget, gpointer data);
-void create_savelog_filesel (void);
+void savelog_show_dialog (void);
 
 #endif
