@@ -121,7 +121,7 @@ scriptwriter_output_firestarter_script ()
 		    "	target=`echo $target | sed 's/ //'g`\n"
 		    "	port=`echo $port | sed 's/ //'g |  sed \"s/-/:/\"`\n"
 		    "	ext_port=`echo $ext_port | sed 's/ //'g |  sed \"s/-/:/\"`\n"
-		    "   int_port_dashed=`echo $int_port | sed 's/ //'g |  sed \"s/:/-/\"`\n"
+		    "	int_port_dashed=`echo $int_port | sed 's/ //'g |  sed \"s/:/-/\"`\n"
 		    "	int_port=`echo $int_port | sed 's/ //'g |  sed \"s/-/:/\"`\n"
 		    "	if [ \"$target\" == \"everyone\" ]; then target=0/0\n"
 		    "	else if [ \"$target\" == \"firewall\" ]; then target=$IP\n"
@@ -166,8 +166,14 @@ scriptwriter_output_firestarter_script ()
 		    "			done < /etc/resolv.conf\n\n"
 
 		    "		if [ \"$NAMESERVER\" != \"\" ]; then\n"
-		    "			sed \"s/domain-name-servers.*$/domain-name-servers $NAMESERVER;/\" /etc/dhcpd.conf > /etc/dhcpd.conf.tmp\n"
-		    "			mv /etc/dhcpd.conf.tmp /etc/dhcpd.conf\n"
+		    "			if [ -f /etc/dhcpd.conf ]; then\n"
+		    "				sed \"s/domain-name-servers.*$/domain-name-servers $NAMESERVER;/\" /etc/dhcpd.conf > /etc/dhcpd.conf.tmp\n"
+		    "				mv /etc/dhcpd.conf.tmp /etc/dhcpd.conf\n"
+		    "			fi\n"
+		    "			if [ -f /etc/dhcp3/dhcpd.conf ]; then\n"
+		    "				sed \"s/domain-name-servers.*$/domain-name-servers $NAMESERVER;/\" /etc/dhcp3/dhcpd.conf > /etc/dhcp3/dhcpd.conf.tmp\n"
+		    "				mv /etc/dhcp3/dhcpd.conf.tmp /etc/dhcp3/dhcpd.conf\n"
+		    "			fi\n"
 		    "		else\n"
 		    "			echo -e \"Warning: Could not determine new DNS settings for DHCP\\nKeeping old configuration\"\n"
 		    "		fi\n"
@@ -396,6 +402,17 @@ scriptwriter_output_configuration ()
 	fprintf (f, "# Block internal broadcast traffic\n"
 		    "BLOCK_INTERNAL_BROADCAST=%s\n", test_bool (PREFS_FW_BLOCK_INTERNAL_BROADCAST));
 
+	fprintf (f, "\n");
+
+	fprintf (f, "# --(Traffic Validation)--\n"
+		    "# Block non-routable traffic on the public interfaces\n"
+		    "BLOCK_NON_ROUTABLES=%s\n", test_bool (PREFS_FW_BLOCK_NON_ROUTABLES));
+
+	fprintf (f, "\n");
+
+	fprintf (f, "# --(Logging)--\n"
+		    "# System log level\n"
+		    "LOG_LEVEL=info\n");
 
 	fprintf (f, "\n");
 
@@ -577,6 +594,7 @@ scriptwriter_write_ppp_hook (void)
 	}
 
 	add_hook (PPP_HOOK_FILE);
+	chmod (PPP_HOOK_FILE, 0755);
 }
 
 void
@@ -702,8 +720,6 @@ create_rules_files (void)
 void
 scriptwriter_output_scripts (void)
 {
-	gboolean script_existed = script_exists(); /* Script existed before we write it*/
-
 	/* Creating the directories for scripts if they are missing */
 	mkdir (FIRESTARTER_RULES_DIR "/firestarter", 00700);
 	mkdir (POLICY_IN_DIR, 00700);
@@ -732,17 +748,6 @@ scriptwriter_output_scripts (void)
 		scriptwriter_write_dhcp_hook ();
 	else
 		scriptwriter_remove_dhcp_hook ();
-
-	if (preferences_get_bool (PREFS_FIRST_RUN) || !script_existed) {
-		/* Mark that the wizard has been run at least once */
-		preferences_set_bool (PREFS_FIRST_RUN, FALSE);
-
-		/* Show the main interface */
-		gui_set_visibility (TRUE);
-
-		/* Finally, start up the newly created firewall */
-                start_firewall ();
-	}
 }
 
 /* Check that the scripts on the system and the scripts that could be
