@@ -29,11 +29,11 @@ Service user_services[] = {
 	{"HTTP", "80"},
 	{"HTTPS", "443"},
 	{"IMAP", "143"},
-	{"NFS", "2049"},
+	{"NFS", "111 2049"},
 	{"NNTP", "119"},
 	{"NTP", "123"},
 	{"POP3", "110"},	
-	{"SMB", "137-139"},
+	{"Samba (SMB)", "137-139 445"},
 	{"SMTP", "25"},
 	{"SSH", "22"},
 	{"Telnet", "23"},
