@@ -1,5 +1,5 @@
 /*---[ service.h ]----------------------------------------------------
- * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
+ * Copyright (C) 2000-2004 Tomas Junnonen (majix@sci.fi)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,8 @@
 #include <config.h>
 #include <gnome.h>
 
-gchar *get_service_name (gint port, gchar *proto);
-gchar *get_service_name_any_protocol (gint port);
+GtkListStore* services_get_model (void);
+gchar *service_get_name (gint port, gchar *proto);
+gchar *service_get_icmp_name (gint type);
 
 #endif
