@@ -38,6 +38,8 @@
 #define HISTORY_LENGTH 5 /* Number of samples to use when averaging the traffic rate */
 #define COLOR_RETIRED_CONNECTION "#6d6d6d"
 
+static gboolean active_connections_visible = FALSE;
+
 static FirewallStatus current_status;
 
 static GtkWidget *connectionview;
@@ -670,15 +672,24 @@ refresh_interface_widgets (gchar *interface, Interface_info *info, GHashTable *a
 	if (widgets == NULL) {
 		gint row = g_hash_table_size (all_widgets)+1;
 		gchar *type;
+		gchar *ext_if, *int_if;
+		
+		ext_if = preferences_get_string (PREFS_FW_EXT_IF);
+		int_if = preferences_get_string (PREFS_FW_INT_IF);
 
-		if (g_str_equal (interface, preferences_get_string (PREFS_FW_EXT_IF)))
+		if (ext_if != NULL && g_str_equal (interface, ext_if))
 			type = g_strdup (_("Internet"));
-		else if (preferences_get_bool (PREFS_FW_NAT) &&
-		         g_str_equal (interface, preferences_get_string (PREFS_FW_INT_IF)))
+		else if (preferences_get_bool (PREFS_FW_NAT) && int_if != NULL &&
+		         g_str_equal (interface, int_if))
 			type = g_strdup (_("Local"));
 		else
 			type = get_pretty_device_name (interface, FALSE);
 
+		if (ext_if != NULL)
+			g_free (ext_if);
+		if (int_if != NULL)
+			g_free (int_if);
+
 		widgets = g_new (Interface_widgets, 1);
 
 		widgets->device = gtk_label_new (NULL);
@@ -787,7 +798,8 @@ update_status_screen (gpointer data)
 	g_hash_table_foreach (interfaces_info, (GHFunc)refresh_interface, interfaces_widgets);
 	g_hash_table_foreach_remove (conntrack_entries, (GHRFunc)update_conntrack_ttl, conntrack_entries);
 
-	connectionview_refresh (conntrack_entries);
+	if (active_connections_visible)
+		connectionview_refresh (conntrack_entries);
 
 	return TRUE;
 }
@@ -892,12 +904,14 @@ expander_cb (GObject *object, GParamSpec *param_spec, gpointer user_data)
 
 	if (gtk_expander_get_expanded (expander)) {
 		gtk_widget_show (contents);
+		active_connections_visible = TRUE;
 	} else { /* Reclaim vertical space on expander collapse */
 		gint width;
 
 		gtk_window_get_size (GTK_WINDOW (Firestarter.window), &width, NULL);
 		gtk_widget_hide (contents);
 		gtk_window_resize (GTK_WINDOW (Firestarter.window), width, 1);
+		active_connections_visible = FALSE;
 	}
 }
 
@@ -936,7 +950,7 @@ create_statusview_page (void)
 		"<b>", _("Firewall"), "</b>", NULL));
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_box_pack_start (GTK_BOX (statuspagebox), frame, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (statuspagebox), frame, FALSE, FALSE, GNOME_PAD_SMALL);
 
 	table = gtk_table_new (3, 3, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(table), GNOME_PAD_SMALL);
