@@ -126,6 +126,8 @@ get_system_log_path (void)
 		} else { /* Try to guess some default syslog location */
 			if (g_file_test ("/var/log/messages", G_FILE_TEST_EXISTS))
 				path = g_strdup ("/var/log/messages");
+			else if (g_file_test ("/var/log/kernel", G_FILE_TEST_EXISTS))
+				path = g_strdup ("/var/log/kernel");
 			else
 				path = NULL;
 		}
@@ -385,10 +387,11 @@ is_a_valid_port (const gchar *port)
 
 	length = strlen (port);
 
-	/* Only numbers or a dash is allowed */
+	/* Only numbers, a dash (range) or a space (delimiter) is allowed */
 	for (i = 0; i < length; i++) {
 		if (!g_ascii_isdigit (port[i]) &&
-		    port[i] != '-') {
+		    port[i] != '-' &&
+		    port[i] != ' ') {
 			return FALSE;
 		}
 	}
