@@ -17,8 +17,8 @@
 #include "xpm/firestarter-pixbufs.h"
 #include "preferences.h"
 #include "dhcp-server.h"
-#include "statusview.h"
 #include "gui.h"
+#include "statusview.h"
 
 enum
 {
@@ -69,14 +69,15 @@ combo_set_active_device (GtkComboBox *combo, gchar *new_if)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
-	gchar *interface;
+	gchar *interface = NULL;
 
 	model = gtk_combo_box_get_model (combo);
 
 	gtk_tree_model_get_iter_first (model, &iter);
 	do {
 		gtk_tree_model_get (model, &iter, 1, &interface, -1);
-		if (g_str_equal (interface, new_if)) {
+		if (interface != NULL && new_if != NULL &&
+		    g_str_equal (interface, new_if)) {
 			gtk_combo_box_set_active_iter (combo, &iter);
 			return TRUE;
 		}
@@ -371,7 +372,7 @@ create_masq_page (Wizard *data)
 }
 
 /* [ create_welcome_page ]
- * Create the contents of the Type of Service filtering page - fnk 12/2000
+ * Create the contents of the welcoming screen
  */
 static GtkWidget*
 create_welcome_page (Wizard *data)
@@ -411,6 +412,57 @@ create_welcome_page (Wizard *data)
 	return hbox;
 }
 
+/* [ create_finish_page ]
+ * Create the contents of the final wizard screen
+ */
+static GtkWidget*
+create_finish_page (Wizard *data)
+{
+	FirewallStatus state;
+	GtkWidget *label;
+	GtkWidget *vbox;
+	GtkWidget *check_start_now;
+
+	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
+
+	label = gtk_label_new (NULL);
+	gtk_label_set_markup (GTK_LABEL (label), g_strconcat (
+		"<b>", _("The wizard is now ready to start your firewall."), "</b>",
+		"\n\n", _("Press the save button to continue, or the back button to review your choices."),
+		NULL)
+	);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+
+	check_start_now = gtk_check_button_new_with_label (_("Start firewall now"));
+	gtk_box_pack_start (GTK_BOX(vbox), check_start_now, FALSE, FALSE, GNOME_PAD_SMALL);
+
+	label = gtk_label_new (NULL);
+	gtk_label_set_markup (GTK_LABEL (label), g_strconcat (
+		"<small>", _(
+		"Tip: If you are connecting to the firewall host remotely you might want to\n"
+		"defer starting the firewall until you have created additional policy."),
+		"</small>", NULL)
+	);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+
+	state = status_get_state ();
+
+	/* Default to starting firewall on the first run, or if the firewall
+	   was already started */
+	if (preferences_get_bool (PREFS_FIRST_RUN) ||
+	    !script_exists () ||
+	    state == STATUS_RUNNING ||
+	    state == STATUS_HIT) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_start_now), TRUE);
+	}
+
+	data->start_firewall = check_start_now;
+
+	return vbox;
+}
+
 /* [ create_page ]
  * Create the default wizard page layout container
  */
@@ -454,22 +506,6 @@ create_page (const char *title)
 	return vbox;
 }
 
-/* [ create_page_with_text ]
- * Create a simple page with text only
- */
-static GtkWidget *
-create_page_with_text (const char *title, const char *text)
-{
-	GtkWidget *label;
-	GtkWidget *page;
-       
-	page = create_page (title);
-	label = gtk_label_new (text);
-	gtk_box_pack_start (GTK_BOX(page), label, TRUE, TRUE, 0);
-
-	return page;
-}
-
 /* [ dialog_response_cb ]
  * Controls what happens when one of the wizard buttons are pressed
  * Possible page flow control code would go here
@@ -527,7 +563,6 @@ dialog_response_cb (GtkDialog *dialog, int response, gpointer data)
 		}
 
 	} else if (response == RESPONSE_FINISHED) {
-		FirewallStatus state;
 
 		save_choices (wizard);
 		scriptwriter_output_scripts ();
@@ -538,19 +573,20 @@ dialog_response_cb (GtkDialog *dialog, int response, gpointer data)
 		    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wizard->dhcp_new_config)))
 			dhcp_server_create_configuration ();
 
-		state = status_get_state ();
+		if (preferences_get_bool (PREFS_FIRST_RUN)) {
+			/* Mark that the wizard has been run at least once */
+			preferences_set_bool (PREFS_FIRST_RUN, FALSE);
+		}
 
-		/* Always start firewall on the first run, otherwise only if the firewall
-		   has already been started */
-		if (preferences_get_bool (PREFS_FIRST_RUN) ||
-		    !script_exists () ||
-		    state == STATUS_RUNNING ||
-		    state == STATUS_HIT)
+		/* Finally, start the firewall */
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wizard->start_firewall)))
 			start_firewall ();
 
 		g_free (wizard);
 		gtk_widget_destroy (GTK_WIDGET(dialog));
 
+		/* Show the main interface */
+		gui_set_visibility (TRUE);
 	} else {
 		if (response == RESPONSE_GO_BACK) {
 			gtk_notebook_set_current_page (GTK_NOTEBOOK(wizard->notebook), --current_page);
@@ -620,19 +656,14 @@ run_wizard (void)
 	alignment = gtk_alignment_new (0.5, 0.5, 0.5, 0.5);
 	gtk_box_pack_start (GTK_BOX(page), alignment, TRUE, TRUE, 0);
 	gtk_container_add (GTK_CONTAINER(alignment), create_masq_page (wizard));
-
-	/* Don't show the NAT page if the hardware doesn't support it */
-	if (is_capable_of_nat ()) {
-		g_ptr_array_add (wizard->pages, page);
-	}
+	g_ptr_array_add (wizard->pages, page);
 
 	/* Final page */
-	page = create_page_with_text (
-		_("Ready to start your firewall"),
-		_("The wizard is now ready to start your firewall.\n\n"
-		  "Press the save button to continue, or the back button\n"
-		  "to review your choices.\n\n"));	
-	g_ptr_array_add (wizard->pages, page);	
+	page = create_page (_("Ready to start your firewall"));
+	alignment = gtk_alignment_new (0.5, 0.5, 0.5, 0.5);
+	gtk_box_pack_start (GTK_BOX(page), alignment, TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER(alignment), create_finish_page (wizard));
+	g_ptr_array_add (wizard->pages, page);
 
 	/* Load pages into notebook */
 	for (i = 0; i < wizard->pages->len; i++) {
